==> jc-1.4.0.tar.gz: java/util/PropertyResourceBundle.h <==
// public class java.util.PropertyResourceBundle

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a5d2d2e272fa4802 java_util_PropertyResourceBundle
// @dep_class b0f2ff51263ebf06 java_util_ResourceBundle

// header file dependencies
// @dep_header java_util_ResourceBundle

#include "java/util/ResourceBundle.h"

#ifndef _JC_java_util_PropertyResourceBundle_H_
#define _JC_java_util_PropertyResourceBundle_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Enumeration$object;
struct _jc_java_util_Properties$object;

// Typedefs
typedef struct _jc_java_util_PropertyResourceBundle$sub_refs	_jc_java_util_PropertyResourceBundle$sub_refs;
typedef struct _jc_java_util_PropertyResourceBundle$sub_nonrefs	_jc_java_util_PropertyResourceBundle$sub_nonrefs;
typedef struct _jc_java_util_PropertyResourceBundle$refs	_jc_java_util_PropertyResourceBundle$refs;
typedef struct _jc_java_util_PropertyResourceBundle$nonrefs	_jc_java_util_PropertyResourceBundle$nonrefs;
typedef struct _jc_java_util_PropertyResourceBundle$object	_jc_java_util_PropertyResourceBundle$object;

typedef const struct _jc_java_util_PropertyResourceBundle$vmethods	_jc_java_util_PropertyResourceBundle$vmethods;
typedef const struct _jc_java_util_PropertyResourceBundle$vtable	_jc_java_util_PropertyResourceBundle$vtable;
typedef const struct _jc_java_util_PropertyResourceBundle$vtype	_jc_java_util_PropertyResourceBundle$vtype;

// Constructors
extern void _jc_java_util_PropertyResourceBundle$method$_init$3887600c17c5e554(_jc_env *, struct _jc_java_util_PropertyResourceBundle$object *, struct _jc_java_io_InputStream$object *);

// Virtual methods
extern struct _jc_object *_jc_java_util_PropertyResourceBundle$method$getKeys$0c3e71a6b21e93a1(_jc_env *, struct _jc_java_util_PropertyResourceBundle$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_PropertyResourceBundle$method$handleGetObject$8a8018cda2e04cd4(_jc_env *, struct _jc_java_util_PropertyResourceBundle$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_PropertyResourceBundle$method_info$getKeys$0c3e71a6b21e93a1;
extern _jc_method _jc_java_util_PropertyResourceBundle$method_info$handleGetObject$8a8018cda2e04cd4;

// Virtual methods structure
struct _jc_java_util_PropertyResourceBundle$vmethods {
	struct _jc_object	*(*getKeys$0c3e71a6b21e93a1)(_jc_env *, struct _jc_java_util_PropertyResourceBundle$object *);
	struct _jc_java_lang_Object$object	*(*handleGetObject$8a8018cda2e04cd4)(_jc_env *, struct _jc_java_util_PropertyResourceBundle$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_java_util_PropertyResourceBundle$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_ResourceBundle$vmethods	java_util_ResourceBundle;
	_jc_java_util_PropertyResourceBundle$vmethods	java_util_PropertyResourceBundle;
};

// Vtype
struct _jc_java_util_PropertyResourceBundle$vtype {
	_jc_type			type;
	_jc_java_util_PropertyResourceBundle$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_PropertyResourceBundle$sub_refs {
	struct _jc_java_util_Properties$object	*properties;
};

// Reference instance fields (object)
struct _jc_java_util_PropertyResourceBundle$refs {
    _jc_java_util_PropertyResourceBundle$sub_refs	java_util_PropertyResourceBundle;
    _jc_java_util_ResourceBundle$sub_refs	java_util_ResourceBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_PropertyResourceBundle$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_PropertyResourceBundle$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_ResourceBundle$sub_nonrefs	java_util_ResourceBundle;
    _jc_java_util_PropertyResourceBundle$sub_nonrefs	java_util_PropertyResourceBundle;
};

// Object instance structure
struct _jc_java_util_PropertyResourceBundle$object {
	_jc_java_util_PropertyResourceBundle$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_PropertyResourceBundle$vtype	*vtype;
	_jc_java_util_PropertyResourceBundle$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_PropertyResourceBundle$vtype _jc_java_util_PropertyResourceBundle$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_PropertyResourceBundle, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_PropertyResourceBundle$class_object;

#endif	/* _JC_java_util_PropertyResourceBundle_H_ */

==> jc-1.4.6.tar.gz: java/util/PropertyResourceBundle.h <==
// public class java.util.PropertyResourceBundle

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a5d2d2e272fa4802 java_util_PropertyResourceBundle
// @dep_class b0f2ff51263ebf06 java_util_ResourceBundle

// header file dependencies
// @dep_header java_util_ResourceBundle

#include "java/util/ResourceBundle.h"

#ifndef _JC_java_util_PropertyResourceBundle_H_
#define _JC_java_util_PropertyResourceBundle_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Enumeration$object;
struct _jc_java_util_Properties$object;

// Typedefs
typedef struct _jc_java_util_PropertyResourceBundle$sub_refs	_jc_java_util_PropertyResourceBundle$sub_refs;
typedef struct _jc_java_util_PropertyResourceBundle$sub_nonrefs	_jc_java_util_PropertyResourceBundle$sub_nonrefs;
typedef struct _jc_java_util_PropertyResourceBundle$refs	_jc_java_util_PropertyResourceBundle$refs;
typedef struct _jc_java_util_PropertyResourceBundle$nonrefs	_jc_java_util_PropertyResourceBundle$nonrefs;
typedef struct _jc_java_util_PropertyResourceBundle$object	_jc_java_util_PropertyResourceBundle$object;

typedef const struct _jc_java_util_PropertyResourceBundle$vmethods	_jc_java_util_PropertyResourceBundle$vmethods;
typedef const struct _jc_java_util_PropertyResourceBundle$vtable	_jc_java_util_PropertyResourceBundle$vtable;
typedef const struct _jc_java_util_PropertyResourceBundle$vtype	_jc_java_util_PropertyResourceBundle$vtype;

// Constructors
extern void _jc_java_util_PropertyResourceBundle$method$_init$3887600c17c5e554(_jc_env *, struct _jc_java_util_PropertyResourceBundle$object *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_java_util_PropertyResourceBundle$method$getKeys$0c3e71a6b21e93a1(_jc_env *, struct _jc_java_util_PropertyResourceBundle$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_PropertyResourceBundle$method$handleGetObject$8a8018cda2e04cd4(_jc_env *, struct _jc_java_util_PropertyResourceBundle$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_PropertyResourceBundle$method_info$getKeys$0c3e71a6b21e93a1;
extern _jc_method _jc_java_util_PropertyResourceBundle$method_info$handleGetObject$8a8018cda2e04cd4;

// Virtual methods structure
struct _jc_java_util_PropertyResourceBundle$vmethods {
	struct _jc_object	*(*getKeys$0c3e71a6b21e93a1)(_jc_env *, struct _jc_java_util_PropertyResourceBundle$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*handleGetObject$8a8018cda2e04cd4)(_jc_env *, struct _jc_java_util_PropertyResourceBundle$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_PropertyResourceBundle$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_ResourceBundle$vmethods	java_util_ResourceBundle;
	_jc_java_util_PropertyResourceBundle$vmethods	java_util_PropertyResourceBundle;
};

// Vtype
struct _jc_java_util_PropertyResourceBundle$vtype {
	_jc_type			type;
	_jc_java_util_PropertyResourceBundle$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_PropertyResourceBundle$sub_refs {
	struct _jc_java_util_Properties$object	*properties;
};

// Reference instance fields (object)
struct _jc_java_util_PropertyResourceBundle$refs {
    _jc_java_util_PropertyResourceBundle$sub_refs	java_util_PropertyResourceBundle;
    _jc_java_util_ResourceBundle$sub_refs	java_util_ResourceBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_PropertyResourceBundle$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_PropertyResourceBundle$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_ResourceBundle$sub_nonrefs	java_util_ResourceBundle;
    _jc_java_util_PropertyResourceBundle$sub_nonrefs	java_util_PropertyResourceBundle;
};

// Object instance structure
struct _jc_java_util_PropertyResourceBundle$object {
	_jc_java_util_PropertyResourceBundle$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_PropertyResourceBundle$vtype	*vtype;
	_jc_java_util_PropertyResourceBundle$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_PropertyResourceBundle$vtype _jc_java_util_PropertyResourceBundle$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_PropertyResourceBundle, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_PropertyResourceBundle$class_object;

#endif	/* _JC_java_util_PropertyResourceBundle_H_ */
